# *****************************************************************************
# Copyright (c) 2024 IBM Corporation and other Contributors.
#
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#
# *****************************************************************************
supportedCatalogs = {
    "amd64": [
        "v9-251010-amd64",
        "v9-250925-amd64",
        "v9-250902-amd64",
        "v9-250828-amd64",
    ],
    "s390x": [
        # No "v9-250925-s390x" catalog for the s390x
        "v9-250902-s390x",
        "v9-250828-s390x",
    ],
    "ppc64le": [
        "v9-251010-ppc64le",
        "v9-250925-ppc64le",
        "v9-250902-ppc64le",
        "v9-250828-ppc64le",
    ],
}
